@@ -35,7 +35,7 @@
 G_BEGIN_DECLS
 
 void          gva_main_init                     (void);
-GvaProcess *  gva_main_build_database           (GError **error);
+gboolean      gva_main_build_database           (GError **error);
 void          gva_main_connect_proxy_cb         (GtkUIManager *manager,
                                                  GtkAction *action,
                                                  GtkWidget *proxy);
