@@ -16,6 +16,14 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * SECTION: gva-mame-process
+ * @short_description: An abstraction of a UNIX process running MAME
+ *
+ * A #GvaMameProcess is a type of #GvaProcess designed specifically for
+ * communicating with a child process running MAME.
+ **/
+
 #ifndef GVA_MAME_PROCESS_H
 #define GVA_MAME_PROCESS_H
 
@@ -46,6 +54,12 @@ G_BEGIN_DECLS
 typedef struct _GvaMameProcess GvaMameProcess;
 typedef struct _GvaMameProcessClass GvaMameProcessClass;
 
+/**
+ * GvaMameProcess:
+ *
+ * Contains only private data that should be read and manipulated using the
+ * functions below.
+ **/
 struct _GvaMameProcess
 {
         GvaProcess parent;
@@ -58,6 +72,7 @@ struct _GvaMameProcessClass
 
 GType           gva_mame_process_get_type       (void);
 GvaProcess *    gva_mame_process_spawn          (const gchar *arguments,
+                                                 gint priority,
                                                  GError **error);
 
 G_END_DECLS
